## What is TMI? ##
TMI(Task Manage Interface) is open source console software for managing user's
tasks.  It provides some method and text-based user interface.  This software is
developed for the various Linux OS and by python.

## Bugs and feature requests ##
This software may have many bugs or few features. Have a bug or a feature request?
Please leave your idea as an issue or pull request, but provide as much detail and context as possible.

## Installation ##
> This software recommends you to use PyPI.(In fact, this is only way)
Supported OS are Linux distributions like Devian, Ubuntu. We plan to don't care any other
OS yet.  
- **Install TMI from PyPI (recommended):**

```sh
sudo pip install tmi
```

If you are using a virtualenv, you may want to avoid using sudo:

```sh
pip install tmi
```

- **Alternatively: install TMI from the GitHub source:**

First, clone TMI using `git`:

```sh
git clone https://github.com/onnoo/TMI.git
```

 Then, `cd` to the TMI folder and run the install command:
```sh
cd TMI
sudo python setup.py install
```

## License ##
Code released under the [MIT License](https://github.com/onnoo/TMI/raw/master/LICENSE).
